@@ -19,7 +19,7 @@ package flags
 import (
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"os"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
@@ -53,12 +53,12 @@ func (t *BuildOutputFileFlag) Set(value string) error {
 	)
 
 	if value == "-" {
-		buf, err = ioutil.ReadAll(os.Stdin)
+		buf, err = io.ReadAll(os.Stdin)
 	} else {
 		if _, err := os.Stat(value); os.IsNotExist(err) {
 			return err
 		}
-		buf, err = ioutil.ReadFile(value)
+		buf, err = os.ReadFile(value)
 	}
 	if err != nil {
 		return err
