@@ -204,6 +204,14 @@ func TestIsErrAndNotRetriable(t *testing.T) {
 			statusCode:  proto.StatusCode_STATUSCHECK_DEADLINE_EXCEEDED,
 			expected:    true,
 		},
+		{
+			description: "unschedule error code",
+			statusCode:  proto.StatusCode_STATUSCHECK_NODE_UNSCHEDULABLE,
+		},
+		{
+			description: "unschedule unknown error",
+			statusCode:  proto.StatusCode_STATUSCHECK_UNKNOWN_UNSCHEDULABLE,
+		},
 		{
 			description: "rollout status nil error",
 			statusCode:  proto.StatusCode_STATUSCHECK_SUCCESS,
