@@ -130,6 +130,10 @@ func (h Helm) generateHelmManifests(ctx context.Context, builds []graph.Artifact
 			return nil, helm.UserErr("construct override args", err)
 		}
 
+		if release.SkipTests {
+			args = append(args, "--skip-tests")
+		}
+
 		namespace, err := helm.ReleaseNamespace(h.namespace, release)
 		if err != nil {
 			return nil, err
@@ -148,10 +152,18 @@ func (h Helm) generateHelmManifests(ctx context.Context, builds []graph.Artifact
 
 		outBuffer := new(bytes.Buffer)
 		errBuffer := new(bytes.Buffer)
-		if err := helm.ExecWithStdoutAndStderr(ctx, h, outBuffer, errBuffer, false, helmEnv, args...); err != nil {
-			return nil, helm.UserErr("std out err", fmt.Errorf(outBuffer.String(), fmt.Errorf(errBuffer.String())))
+
+		err = helm.ExecWithStdoutAndStderr(ctx, h, outBuffer, errBuffer, false, helmEnv, args...)
+		errorMsg := errBuffer.String()
+
+		if len(errorMsg) > 0 {
+			log.Entry(ctx).Errorf(errorMsg)
 		}
-		log.Entry(ctx).Errorf(errBuffer.String())
+
+		if err != nil {
+			return nil, helm.UserErr("std out err", fmt.Errorf(outBuffer.String(), fmt.Errorf(errorMsg)))
+		}
+
 		renderedManifests.Append(outBuffer.Bytes())
 	}
 
