@@ -38,13 +38,13 @@ const (
 	defaultCloudBuildGradleImage = "gcr.io/cloud-builders/gradle"
 	defaultCloudBuildKanikoImage = kaniko.DefaultImage
 	defaultCloudBuildPackImage   = "gcr.io/k8s-skaffold/pack"
+	defaultCloudBuildKoImage     = "gcr.io/k8s-skaffold/skaffold"
 )
 
 // Set makes sure default values are set on a SkaffoldConfig.
 func Set(c *latest.SkaffoldConfig) error {
 	defaultToLocalBuild(c)
 	setDefaultTagger(c)
-	setDefaultKustomizePath(c)
 	setDefaultLogsConfig(c)
 
 	for _, a := range c.Build.Artifacts {
@@ -76,12 +76,20 @@ func Set(c *latest.SkaffoldConfig) error {
 		}
 	}
 
+	withLocalBuild(c, func(lb *latest.LocalBuild) {
+		// don't set build concurrency if there are no artifacts in the current config
+		if len(c.Build.Artifacts) > 0 {
+			setDefaultConcurrency(lb)
+		}
+	})
+
 	withCloudBuildConfig(c,
 		setDefaultCloudBuildDockerImage,
 		setDefaultCloudBuildMavenImage,
 		setDefaultCloudBuildGradleImage,
 		setDefaultCloudBuildKanikoImage,
 		setDefaultCloudBuildPackImage,
+		setDefaultCloudBuildKoImage,
 	)
 
 	if err := withClusterConfig(c,
@@ -105,10 +113,45 @@ func Set(c *latest.SkaffoldConfig) error {
 	return nil
 }
 
+// SetDefaultRenderer sets the default manifests to rawYaml.
+func SetDefaultRenderer(c *latest.SkaffoldConfig) {
+	if len(c.Render.Generate.Kpt) > 0 {
+		return
+	}
+	if len(c.Render.Generate.RawK8s) > 0 {
+		if c.Deploy.KubectlDeploy == nil && c.Deploy.CloudRunDeploy == nil {
+			log.Entry(context.TODO()).Debug("Found raw k8s manifests without cloud run deploy, adding kubectl deployer")
+			c.Deploy.KubectlDeploy = &latest.KubectlDeploy{}
+		}
+		return
+	}
+	if c.Render.Generate.Kustomize != nil {
+		return
+	}
+	if c.Render.Generate.Helm != nil {
+		return
+	}
+	if c.Deploy.LegacyHelmDeploy != nil {
+		return
+	}
+	if c.Deploy.DockerDeploy != nil {
+		return
+	}
+	if c.Deploy.CloudRunDeploy != nil {
+		return
+	}
+	// Set default manifests to "k8s/*.yaml", same as v1.
+	c.Render.Generate.RawK8s = constants.DefaultKubectlManifests
+}
+
 // SetDefaultDeployer adds a default kubectl deploy configuration.
 func SetDefaultDeployer(c *latest.SkaffoldConfig) {
-	defaultToKubectlDeploy(c)
-	setDefaultKubectlManifests(c)
+	if c.Deploy.DeployType != (latest.DeployType{}) {
+		return
+	}
+
+	log.Entry(context.TODO()).Debug("Defaulting deploy type to kubectl")
+	c.Deploy.DeployType.KubectlDeploy = &latest.KubectlDeploy{}
 }
 
 func defaultToLocalBuild(c *latest.SkaffoldConfig) {
@@ -120,13 +163,18 @@ func defaultToLocalBuild(c *latest.SkaffoldConfig) {
 	c.Build.BuildType.LocalBuild = &latest.LocalBuild{}
 }
 
-func defaultToKubectlDeploy(c *latest.SkaffoldConfig) {
-	if c.Deploy.DeployType != (latest.DeployType{}) {
-		return
+func withLocalBuild(c *latest.SkaffoldConfig, operations ...func(*latest.LocalBuild)) {
+	if local := c.Build.LocalBuild; local != nil {
+		for _, operation := range operations {
+			operation(local)
+		}
 	}
+}
 
-	log.Entry(context.TODO()).Debug("Defaulting deploy type to kubectl")
-	c.Deploy.DeployType.KubectlDeploy = &latest.KubectlDeploy{}
+func setDefaultConcurrency(local *latest.LocalBuild) {
+	if local.Concurrency == nil {
+		local.Concurrency = &constants.DefaultLocalConcurrency
+	}
 }
 
 func withCloudBuildConfig(c *latest.SkaffoldConfig, operations ...func(*latest.GoogleCloudBuild)) {
@@ -157,6 +205,10 @@ func setDefaultCloudBuildPackImage(gcb *latest.GoogleCloudBuild) {
 	gcb.PackImage = valueOrDefault(gcb.PackImage, defaultCloudBuildPackImage)
 }
 
+func setDefaultCloudBuildKoImage(gcb *latest.GoogleCloudBuild) {
+	gcb.KoImage = valueOrDefault(gcb.KoImage, defaultCloudBuildKoImage)
+}
+
 func setDefaultTagger(c *latest.SkaffoldConfig) {
 	if c.Build.TagPolicy != (latest.TagPolicy{}) {
 		return
@@ -165,22 +217,6 @@ func setDefaultTagger(c *latest.SkaffoldConfig) {
 	c.Build.TagPolicy = latest.TagPolicy{GitTagger: &latest.GitTagger{}}
 }
 
-func setDefaultKustomizePath(c *latest.SkaffoldConfig) {
-	kustomize := c.Deploy.KustomizeDeploy
-	if kustomize == nil {
-		return
-	}
-	if len(kustomize.KustomizePaths) == 0 {
-		kustomize.KustomizePaths = []string{constants.DefaultKustomizationPath}
-	}
-}
-
-func setDefaultKubectlManifests(c *latest.SkaffoldConfig) {
-	if c.Deploy.KubectlDeploy != nil && len(c.Deploy.KubectlDeploy.Manifests) == 0 && len(c.Deploy.KubectlDeploy.RemoteManifests) == 0 {
-		c.Deploy.KubectlDeploy.Manifests = constants.DefaultKubectlManifests
-	}
-}
-
 func setDefaultLogsConfig(c *latest.SkaffoldConfig) {
 	if c.Deploy.Logs.Prefix == "" {
 		c.Deploy.Logs.Prefix = "container"
@@ -212,6 +248,10 @@ func setBuildpackArtifactDefaults(a *latest.BuildpackArtifact) {
 			Paths: []string{"."},
 		}
 	}
+	if a.Builder == "" && len(a.Buildpacks) == 0 {
+		a.Builder = constants.DefaultBuildpacksBuilderImage
+		a.TrustBuilder = true
+	}
 }
 
 func setDockerArtifactDefaults(a *latest.DockerArtifact) {
@@ -227,13 +267,13 @@ func setDefaultSync(a *latest.Artifact) {
 		if len(a.Sync.Manual) == 0 && len(a.Sync.Infer) == 0 && a.Sync.Auto == nil {
 			switch {
 			case a.JibArtifact != nil || a.BuildpackArtifact != nil:
-				a.Sync.Auto = util.BoolPtr(true)
+				a.Sync.Auto = util.Ptr(true)
 			default:
 				a.Sync.Infer = []string{"**/*"}
 			}
 		}
 	} else if a.BuildpackArtifact != nil {
-		a.Sync = &latest.Sync{Auto: util.BoolPtr(true)}
+		a.Sync = &latest.Sync{Auto: util.Ptr(true)}
 	}
 }
 
