@@ -13,6 +13,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package sync
 
 import (
@@ -650,7 +651,7 @@ func TestNewSyncItem(t *testing.T) {
 				},
 				ImageName: "test",
 				Sync: &latest.Sync{
-					Auto: util.BoolPtr(true),
+					Auto: util.Ptr(true),
 				},
 				Workspace: ".",
 			},
@@ -690,7 +691,7 @@ func TestNewSyncItem(t *testing.T) {
 				},
 				ImageName: "test",
 				Sync: &latest.Sync{
-					Auto: util.BoolPtr(true),
+					Auto: util.Ptr(true),
 				},
 				Workspace: ".",
 			},
@@ -724,7 +725,7 @@ func TestNewSyncItem(t *testing.T) {
 				ImageName: "test",
 				Workspace: ".",
 				Sync: &latest.Sync{
-					Auto: util.BoolPtr(true),
+					Auto: util.Ptr(true),
 				},
 				ArtifactType: latest.ArtifactType{
 					JibArtifact: &latest.JibArtifact{},
@@ -747,6 +748,42 @@ func TestNewSyncItem(t *testing.T) {
 				Delete: nil,
 			},
 		},
+
+		// Infer with Ko
+		{
+			description: "infer: ko static assets",
+			artifact: &latest.Artifact{
+				ArtifactType: latest.ArtifactType{
+					KoArtifact: &latest.KoArtifact{},
+				},
+				ImageName: "test",
+				Sync: &latest.Sync{
+					Infer: []string{"kodata/**/*"},
+				},
+			},
+			builds: []graph.Artifact{{
+				ImageName: "test",
+				Tag:       "test:123",
+			}},
+			evt: filemon.Events{
+				Added: []string{filepath.Join("kodata", "foo", "bar.html")},
+				Modified: []string{
+					filepath.Join("kodata", "frob", "baz.js"),
+					"main.go",
+				},
+				Deleted: []string{filepath.Join("kodata", "corge", "grault.css")},
+			},
+			expected: &Item{
+				Image: "test:123",
+				Copy: map[string][]string{
+					filepath.Join("kodata", "foo", "bar.html"): {"/var/run/ko/foo/bar.html"},
+					filepath.Join("kodata", "frob", "baz.js"):  {"/var/run/ko/frob/baz.js"},
+				},
+				Delete: map[string][]string{
+					filepath.Join("kodata", "corge", "grault.css"): {"/var/run/ko/corge/grault.css"},
+				},
+			},
+		},
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
@@ -1071,18 +1108,18 @@ func TestInit(t *testing.T) {
 		},
 		{
 			description: "sync on, auto on, non-jib",
-			artifact:    &latest.Artifact{Sync: &latest.Sync{Auto: util.BoolPtr(true)}},
+			artifact:    &latest.Artifact{Sync: &latest.Sync{Auto: util.Ptr(true)}},
 			shouldInit:  false,
 		},
 		{
 			description: "sync on, auto on, jib",
-			artifact:    &latest.Artifact{ArtifactType: latest.ArtifactType{JibArtifact: &latest.JibArtifact{}}, Sync: &latest.Sync{Auto: util.BoolPtr(true)}},
+			artifact:    &latest.Artifact{ArtifactType: latest.ArtifactType{JibArtifact: &latest.JibArtifact{}}, Sync: &latest.Sync{Auto: util.Ptr(true)}},
 			shouldInit:  true,
 			initErrors:  false,
 		},
 		{
 			description: "sync on, auto on, jib, init fails",
-			artifact:    &latest.Artifact{ArtifactType: latest.ArtifactType{JibArtifact: &latest.JibArtifact{}}, Sync: &latest.Sync{Auto: util.BoolPtr(true)}},
+			artifact:    &latest.Artifact{ArtifactType: latest.ArtifactType{JibArtifact: &latest.JibArtifact{}}, Sync: &latest.Sync{Auto: util.Ptr(true)}},
 			shouldInit:  true,
 			initErrors:  true,
 		},
