@@ -43,18 +43,19 @@ func TestSetAbsFilePaths(t *testing.T) {
 							{ImageName: "foo2", Workspace: "/a/foo"},
 						},
 					},
-					Deploy: latest.DeployConfig{
-						DeployType: latest.DeployType{
-							KptDeploy:     &latest.KptDeploy{Dir: "."},
-							KubectlDeploy: &latest.KubectlDeploy{Manifests: []string{"foo/*", "/a/foo/*"}},
-							HelmDeploy: &latest.HelmDeploy{Releases: []latest.HelmRelease{
+					Render: latest.RenderConfig{
+						Generate: latest.Generate{
+							RawK8s: []string{"foo/*", "/a/foo/*"},
+							Kpt:    []string{"."},
+							Helm: &latest.Helm{Releases: []latest.HelmRelease{
 								{ChartPath: "../charts", ValuesFiles: []string{"./values1.yaml", "./values2.yaml"}, SetFiles: map[string]string{"envFile": "./values3.yaml", "configFile": "./values4.yaml", "anotherFile": "/c/values5.yaml"}},
-								{RemoteChart: "foo/bar", ValuesFiles: []string{"./values1.yaml", "./values2.yaml"}, SetFiles: map[string]string{"envFile": "./values3.yaml", "configFile": "./values4.yaml", "anotherFile": "/c/values5.yaml"}},
-							}},
+								{RemoteChart: "foo/bar", ValuesFiles: []string{"./values1.yaml", "./values2.yaml"}, SetFiles: map[string]string{"envFile": "./values3.yaml", "configFile": "./values4.yaml", "anotherFile": "/c/values5.yaml"}}},
+							},
 						},
 					},
 				},
 			},
+
 			base: "/a/b",
 			expected: &latest.SkaffoldConfig{
 				Pipeline: latest.Pipeline{
@@ -64,11 +65,11 @@ func TestSetAbsFilePaths(t *testing.T) {
 							{ImageName: "foo2", Workspace: "/a/foo"},
 						},
 					},
-					Deploy: latest.DeployConfig{
-						DeployType: latest.DeployType{
-							KptDeploy:     &latest.KptDeploy{Dir: "/a/b"},
-							KubectlDeploy: &latest.KubectlDeploy{Manifests: []string{"/a/b/foo/*", "/a/foo/*"}},
-							HelmDeploy: &latest.HelmDeploy{Releases: []latest.HelmRelease{
+					Render: latest.RenderConfig{
+						Generate: latest.Generate{
+							RawK8s: []string{"/a/b/foo/*", "/a/foo/*"},
+							Kpt:    []string{"/a/b"},
+							Helm: &latest.Helm{Releases: []latest.HelmRelease{
 								{ChartPath: "/a/charts", ValuesFiles: []string{"/a/b/values1.yaml", "/a/b/values2.yaml"}, SetFiles: map[string]string{"envFile": "/a/b/values3.yaml", "configFile": "/a/b/values4.yaml", "anotherFile": "/c/values5.yaml"}},
 								{RemoteChart: "foo/bar", ValuesFiles: []string{"/a/b/values1.yaml", "/a/b/values2.yaml"}, SetFiles: map[string]string{"envFile": "/a/b/values3.yaml", "configFile": "/a/b/values4.yaml", "anotherFile": "/c/values5.yaml"}},
 							}},
